
/*
 * Copyright (c) 1999 David Stes.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Library General Public License as published 
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: shell.m,v 1.1.1.1 2000/06/07 21:09:26 stes Exp $
 */

#include "config.h"
#include <stddef.h>
#include <stdlib.h>
#include <assert.h>
#include <ctype.h>
#include <string.h>
#include <sys/stat.h>

#ifndef __OBJECT_INCLUDED__
#define __OBJECT_INCLUDED__
#include <stdio.h> /* FILE */
#include "Object.h" /* Stepstone Object.h assumes #import */
#endif
#include <ocstring.h>
#include <set.h>
#include <ordcltn.h>
#include <sequence.h>
#include <dictnary.h>

#include "cmd.h"
#include "shell.h"
#include "loaded.h"

@implementation Shell

- edit
{
  edit++;
  return self;
}

- what:x
{
  what = x;
  return self;
}

- what
{
  return what;
}

- dosystem:(char*)s
{
  system(s);
  return self;
}

- go
{
  if (what!=nil && [what str]!=NULL) {
    if (edit) {
      id buf = [String str:"vi </dev/tty >/dev/tty"];
      [buf concat:what];
      [self dosystem:[buf str]];
    } else {
      [self dosystem:[what str]];
    }
  }
  /* if (automake) */ [Loaded make];
  return self;
}

@end

